@@ -3,6 +3,7 @@ import json
 import random
 import logging
 import threading
+import time
 from binascii import crc32
 from requests.models import Request, Response
 from localstack import config
@@ -210,10 +211,12 @@ class ProxyListenerDynamoDB(ProxyListener):
         if not action:
             return
 
+        # upgrade event version to 1.1
         record = {
             'eventID': '1',
-            'eventVersion': '1.0',
+            'eventVersion': '1.1',
             'dynamodb': {
+                'ApproximateCreationDateTime': time.time(),
                 'StreamViewType': 'NEW_AND_OLD_IMAGES',
                 'SizeBytes': -1
             },
@@ -224,12 +227,15 @@ class ProxyListenerDynamoDB(ProxyListener):
 
         if action == '%s.UpdateItem' % ACTION_PREFIX:
             if response.status_code == 200:
+                existing_item = self._thread_local('existing_item')
+                record['eventName'] = 'INSERT' if not existing_item else 'MODIFY'
+
                 updated_item = find_existing_item(data)
                 if not updated_item:
                     return
-                record['eventName'] = 'MODIFY'
                 record['dynamodb']['Keys'] = data['Key']
-                record['dynamodb']['OldImage'] = self._thread_local('existing_item')
+                if existing_item:
+                    record['dynamodb']['OldImage'] = existing_item
                 record['dynamodb']['NewImage'] = updated_item
                 record['dynamodb']['SizeBytes'] = len(json.dumps(updated_item))
         elif action == '%s.BatchWriteItem' % ACTION_PREFIX:
@@ -377,7 +383,10 @@ class ProxyListenerDynamoDB(ProxyListener):
 
     def prepare_transact_write_item_records(self, record, data):
         records = []
-        for i, request in enumerate(data['TransactItems']):
+        # Fix issue #2745: existing_items only contain the Put/Update/Delete records,
+        # so we will increase the index based on these events
+        i = 0
+        for request in data['TransactItems']:
             put_request = request.get('Put')
             if put_request:
                 existing_item = self._thread_local('existing_items')[i]
@@ -393,6 +402,7 @@ class ProxyListenerDynamoDB(ProxyListener):
                     new_record['dynamodb']['OldImage'] = existing_item
                 new_record['eventSourceARN'] = aws_stack.dynamodb_table_arn(table_name)
                 records.append(new_record)
+                i += 1
             update_request = request.get('Update')
             if update_request:
                 table_name = update_request['TableName']
@@ -409,6 +419,7 @@ class ProxyListenerDynamoDB(ProxyListener):
                 new_record['dynamodb']['NewImage'] = updated_item
                 new_record['eventSourceARN'] = aws_stack.dynamodb_table_arn(table_name)
                 records.append(new_record)
+                i += 1
             delete_request = request.get('Delete')
             if delete_request:
                 table_name = delete_request['TableName']
@@ -421,6 +432,7 @@ class ProxyListenerDynamoDB(ProxyListener):
                 new_record['dynamodb']['OldImage'] = self._thread_local('existing_items')[i]
                 new_record['eventSourceARN'] = aws_stack.dynamodb_table_arn(table_name)
                 records.append(new_record)
+                i += 1
         return records
 
     def delete_all_event_source_mappings(self, table_arn):
