@@ -44,7 +44,8 @@ PLUGIN_SCOPE_COMMANDS = 'commands'
 API_DEPENDENCIES = {
     'dynamodbstreams': ['kinesis'],
     'es': ['elasticsearch'],
-    'lambda': ['logs']
+    'lambda': ['logs'],
+    'kinesis': ['dynamodb']
 }
 # composites define an abstract name like "serverless" that maps to a set of services
 API_COMPOSITES = {
@@ -191,6 +192,9 @@ def get_main_container_ip():
 
 def setup_logging():
     # determine and set log level
+    if PLUGINS_LOADED.get('_logging_'):
+        return
+    PLUGINS_LOADED['_logging_'] = True
     log_level = logging.DEBUG if is_debug() else logging.INFO
     logging.basicConfig(level=log_level, format=LOG_FORMAT, datefmt=LOG_DATE_FORMAT)
 
@@ -300,6 +304,8 @@ class PortMappings(object):
             return
         if int(port) <= 0:
             raise Exception('Unable to add mapping for invalid port: %s' % port)
+        if self.contains(port):
+            return
         for from_range, to_range in self.mappings.items():
             if not self.in_expanded_range(port, from_range):
                 continue
@@ -318,6 +324,11 @@ class PortMappings(object):
 
         return ' '.join([entry(k, v) for k, v in self.mappings.items()])
 
+    def contains(self, port):
+        for from_range, to_range in self.mappings.items():
+            if self.in_range(port, from_range):
+                return True
+
     def in_range(self, port, range):
         return port >= range[0] and port <= range[1]
 
@@ -374,7 +385,6 @@ def start_infra_in_docker():
     # prepare APIs
     canonicalize_api_names()
 
-    services = os.environ.get('SERVICES', '')
     entrypoint = os.environ.get('ENTRYPOINT', '')
     cmd = os.environ.get('CMD', '')
     user_flags = config.DOCKER_FLAGS
@@ -512,9 +522,8 @@ class FuncThread(threading.Thread):
             LOG.warning('Not implemented: FuncThread.stop(..)')
 
 
-def run(cmd, print_error=True, asynchronous=False, stdin=False,
-        stderr=subprocess.STDOUT, outfile=None, env_vars=None, inherit_cwd=False,
-        inherit_env=True, tty=False):
+def run(cmd, print_error=True, asynchronous=False, stdin=False, stderr=subprocess.STDOUT,
+        outfile=None, env_vars=None, inherit_cwd=False, inherit_env=True, tty=False):
     env_dict = os.environ.copy() if inherit_env else {}
     if env_vars:
         env_dict.update(env_vars)
@@ -574,19 +583,18 @@ def run(cmd, print_error=True, asynchronous=False, stdin=False,
 
 
 def is_mac_os():
-    try:
-        out = to_str(subprocess.check_output('uname -a', shell=True))
-        return 'Darwin' in out
-    except subprocess.CalledProcessError:
-        return False
+    return 'Darwin' in get_uname()
 
 
 def is_linux():
+    return 'Linux' in get_uname()
+
+
+def get_uname():
     try:
-        out = to_str(subprocess.check_output('uname -a', shell=True))
-        return 'Linux' in out
-    except subprocess.CalledProcessError:
-        return False
+        return to_str(subprocess.check_output('uname -a', shell=True))
+    except Exception:
+        return ''
 
 
 def mkdir(folder):
